@@ -8,7 +8,7 @@ import re
 import sys
 import time
 import warnings
-from functools import partial
+from functools import lru_cache, partial
 from math import floor
 
 from polyglot.builtins import codepoint_to_chr, hasenv, native_string_type
@@ -56,6 +56,7 @@ def _init_mimetypes():
     _mt_inited = True
 
 
+@lru_cache(4096)
 def guess_type(*args, **kwargs):
     import mimetypes
     if not _mt_inited:
@@ -449,13 +450,19 @@ def my_unichr(num):
     except (ValueError, OverflowError):
         return '?'
 
+XML_ENTITIES = {
+    '"' : '&quot;',
+    "'" : '&apos;',
+    '<' : '&lt;',
+    '>' : '&gt;',
+    '&' : '&amp;'
+}
 
-def entity_to_unicode(match, exceptions=[], encoding='cp1252',
-        result_exceptions={}):
+def entity_to_unicode(match, exceptions=(), encoding=None, result_exceptions={}):
     '''
     :param match: A match object such that '&'+match.group(1)';' is the entity.
 
-    :param exceptions: A list of entities to not convert (Each entry is the name of the entity, e.g. 'apos' or '#1234'
+    :param exceptions: A list of entities to not convert (Each entry is the name of the entity, e.g. 'apos' or '#1234)'
 
     :param encoding: The encoding to use to decode numeric entities between 128 and 256.
     If None, the Unicode UCS encoding is used. A common encoding is cp1252.
@@ -465,61 +472,46 @@ def entity_to_unicode(match, exceptions=[], encoding='cp1252',
     Convenient way to specify exception for things like < or > that can be
     specified by various actual entities.
     '''
-    def check(ch):
-        return result_exceptions.get(ch, ch)
-
-    ent = match.group(1)
-    if ent in exceptions:
-        return '&'+ent+';'
-    if ent in {'apos', 'squot'}:  # squot is generated by some broken CMS software
-        return check("'")
-    if ent == 'hellips':
-        ent = 'hellip'
-    if ent.startswith('#'):
-        try:
-            if ent[1] in ('x', 'X'):
-                num = int(ent[2:], 16)
-            else:
-                num = int(ent[1:])
-        except:
-            return '&'+ent+';'
-        if encoding is None or num > 255:
-            return check(my_unichr(num))
-        try:
-            return check(bytes(bytearray((num,))).decode(encoding))
-        except UnicodeDecodeError:
-            return check(my_unichr(num))
-    from calibre.ebooks.html_entities import html5_entities
+    from calibre.ebooks.html_entities import entity_to_unicode_in_python
     try:
-        return check(html5_entities[ent])
-    except KeyError:
-        pass
-    from polyglot.html_entities import name2codepoint
-    try:
-        return check(my_unichr(name2codepoint[ent]))
-    except KeyError:
-        return '&'+ent+';'
+        from calibre_extensions.fast_html_entities import replace_all_entities
+    except ImportError:  # Running from source without updated binaries
+        return entity_to_unicode_in_python(match, exceptions, encoding, result_exceptions)
+    if not encoding and not exceptions and (not result_exceptions or result_exceptions is XML_ENTITIES):
+        return replace_all_entities(match.group(), result_exceptions is XML_ENTITIES)
+    return entity_to_unicode_in_python(match, exceptions, encoding, result_exceptions)
 
 
-_ent_pat = re.compile(r'&(\S+?);')
-xml_entity_to_unicode = partial(entity_to_unicode, result_exceptions={
-    '"' : '&quot;',
-    "'" : '&apos;',
-    '<' : '&lt;',
-    '>' : '&gt;',
-    '&' : '&amp;'})
+xml_entity_to_unicode = partial(entity_to_unicode, result_exceptions=XML_ENTITIES)
 
 
-def replace_entities(raw, encoding='cp1252'):
-    return _ent_pat.sub(partial(entity_to_unicode, encoding=encoding), raw)
+@lru_cache(2)
+def entity_regex():
+    return re.compile(r'&(\S+?);')
 
 
-def xml_replace_entities(raw, encoding='cp1252'):
-    return _ent_pat.sub(partial(xml_entity_to_unicode, encoding=encoding), raw)
+def replace_entities(raw, encoding=None):
+    if encoding is None:
+        try:
+            from calibre_extensions.fast_html_entities import replace_all_entities
+            replace_all_entities(raw)
+        except ImportError:  # Running from source without updated binaries
+            pass
+    return entity_regex().sub(partial(entity_to_unicode, encoding=encoding), raw)
+
+
+def xml_replace_entities(raw, encoding=None):
+    if encoding is None:
+        try:
+            from calibre_extensions.fast_html_entities import replace_all_entities
+            replace_all_entities(raw, True)
+        except ImportError:  # Running from source without updated binaries
+            pass
+    return entity_regex().sub(partial(xml_entity_to_unicode, encoding=encoding), raw)
 
 
 def prepare_string_for_xml(raw, attribute=False):
-    raw = _ent_pat.sub(entity_to_unicode, raw)
+    raw = replace_entities(raw)
     raw = raw.replace('&', '&amp;').replace('<', '&lt;').replace('>', '&gt;')
     if attribute:
         raw = raw.replace('"', '&quot;').replace("'", '&apos;')
