@@ -75,6 +75,7 @@ class Convert:
         self.dest_dir = dest_dir or os.getcwd()
         self.mi = self.docx.metadata
         self.body = BODY()
+        self.uuid = uuid.uuid4().hex
         self.theme = Theme(self.namespace)
         self.settings = Settings(self.namespace)
         self.tables = Tables(self.namespace)
@@ -241,7 +242,7 @@ class Convert:
         self.fields.polish_markup(self.object_map)
 
         self.log.debug('Cleaning up redundant markup generated by Word')
-        self.cover_image = cleanup_markup(self.log, self.html, self.styles, self.dest_dir, self.detect_cover, self.namespace.XPath)
+        self.cover_image = cleanup_markup(self.log, self.html, self.styles, self.dest_dir, self.detect_cover, self.namespace.XPath, self.uuid)
 
         return self.write(doc)
 
@@ -713,6 +714,7 @@ class Convert:
                     l.set('role', 'doc-noteref')
                     text.add_elem(l)
                     ans.append(text.elem)
+                    ans.set('data-noteref-container', self.uuid)
             elif self.namespace.is_tag(child, 'w:tab'):
                 spaces = int(math.ceil((self.settings.default_tab_stop / 36) * 6))
                 text.add_elem(SPAN(NBSP * spaces))
