@@ -8,6 +8,7 @@ from qt.core import QComboBox, QDialog, QDialogButtonBox, QFormLayout, QIcon, QL
 
 from calibre.gui2 import error_dialog, gprefs, question_dialog
 from calibre.gui2.actions import InterfaceAction, show_menu_under_widget
+from calibre.gui2.geometry import _restore_geometry, delete_geometry, save_geometry
 from calibre.utils.icu import sort_key
 
 
@@ -166,8 +167,12 @@ class LayoutActions(InterfaceAction):
 
          Throws KeyError if the name doesn't exist.
         '''
-        layouts = gprefs['saved_layouts']
         # This can be called by plugins so let the exception fly
+
+        # Restore the application window geometry if we have it.
+        _restore_geometry(self.gui, gprefs, f'saved_layout_{name}')
+        # Now the panel sizes inside the central widget
+        layouts = gprefs['saved_layouts']
         settings = layouts[name]
         # Order is important here. change_layout() must be called before
         # unserializing the settings or panes like book details won't display
@@ -201,6 +206,9 @@ class LayoutActions(InterfaceAction):
         :param:`name` The name for the settings.
         :param:`settings`: The gui layout settings to save.
         '''
+        # Save the main window geometry.
+        save_geometry(self.gui, gprefs, f'saved_layout_{name}')
+        # Now the panel sizes inside the central widget
         layouts = gprefs['saved_layouts']
         layouts.update({name: settings})
         gprefs['saved_layouts'] = layouts
@@ -218,6 +226,9 @@ class LayoutActions(InterfaceAction):
                                    _('Do you really want to delete the saved layout {0}?').format(name),
                                    skip_dialog_name='delete_saved_gui_layout'):
                 return
+
+        # The information is stored as 2 preferences. Delete them both.
+        delete_geometry(gprefs, f'saved_layout_{name}')
         layouts = gprefs['saved_layouts']
         layouts.pop(name, None)
         self.populate_menu()
