@@ -57,10 +57,33 @@ class TableItem(QTableWidgetItem):
         return self.sort_key < other.sort_key
 
 
+class CountTableItem(QTableWidgetItem):
+
+    def __init__(self, val):
+        QTableWidgetItem.__init__(self, str(val))
+        self.val = val
+        self.setTextAlignment(Qt.AlignmentFlag.AlignRight|Qt.AlignmentFlag.AlignVCenter)
+        self.setFlags(Qt.ItemFlag.ItemIsEnabled)
+
+    def setText(self, val):
+        self.val = val
+        QTableWidgetItem.setText(self, str(val))
+
+    def set_sort_key(self):
+        pass
+
+    def __ge__(self, other):
+        return self.val >= other.val
+
+    def __lt__(self, other):
+        return self.val < other.val
+
+
 AUTHOR_COLUMN = 0
 AUTHOR_SORT_COLUMN = 1
-LINK_COLUMN = 2
-NOTES_COLUMN = 3
+COUNTS_COLUMN = 2
+LINK_COLUMN = 3
+NOTES_COLUMN = 4
 
 
 class EditColumnDelegate(QStyledItemDelegate):
@@ -83,7 +106,8 @@ class EditColumnDelegate(QStyledItemDelegate):
         if index.column() == NOTES_COLUMN:
             self.notes_utilities.edit_note(self.table.itemFromIndex(index))
             return None
-
+        if index.column() == COUNTS_COLUMN:
+            return None
         from calibre.gui2.widgets import EnLineEdit
         editor = EnLineEdit(parent)
         editor.setClearButtonEnabled(True)
@@ -132,8 +156,8 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
 
         self.find_aut_func = find_aut_func
         self.table.resizeColumnsToContents()
-        if self.table.columnWidth(2) < 200:
-            self.table.setColumnWidth(2, 200)
+        if self.table.columnWidth(LINK_COLUMN) < 200:
+            self.table.setColumnWidth(LINK_COLUMN, 200)
 
         # set up the cellChanged signal only after the table is filled
         self.ignore_cell_changed = False
@@ -193,13 +217,14 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
         self.original_authors = {}
         auts = db.new_api.author_data()
         self.completion_data = []
+        counts = db.new_api.get_usage_count_by_id('authors')
         for id_, v in auts.items():
             name = v['name']
             name = name.replace('|', ',')
             self.completion_data.append(name)
-            self.authors[id_] = {'name': name, 'sort': v['sort'], 'link': v['link']}
-            self.original_authors[id_] = {'name': name, 'sort': v['sort'],
-                                          'link': v['link']}
+            vals = {'name': name, 'sort': v['sort'], 'link': v['link'], 'count':counts[id_]}
+            self.authors[id_] = vals
+            self.original_authors[id_] = vals.copy()
 
         if prefs['use_primary_find_in_search']:
             self.string_contains = primary_contains
@@ -211,6 +236,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
         self.author_sort_order = 0
         self.link_order = 1
         self.notes_order = 1
+        self.count_order = 1
         self.table.setItemDelegate(EditColumnDelegate(self.completion_data, self.table,
                                                       self.notes_utilities, self.get_item_id))
         self.show_table(id_to_select, select_sort, select_link, is_first_letter)
@@ -260,7 +286,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
 
         self.table.blockSignals(True)
         self.table.clear()
-        self.table.setColumnCount(4)
+        self.table.setColumnCount(5)
 
         self.table.setRowCount(len(auts_to_show))
         row = 0
@@ -269,19 +295,21 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
         for id_, v in self.authors.items():
             if id_ not in auts_to_show:
                 continue
-            name, sort, link = (v['name'], v['sort'], v['link'])
+            name, sort, link, count = (v['name'], v['sort'], v['link'], v['count'])
             name = name.replace('|', ',')
 
             name_item = TableItem(name)
             name_item.setData(Qt.ItemDataRole.UserRole, id_)
             sort_item = TableItem(sort)
             link_item = TableItem(link)
+            count_item = CountTableItem(count)
 
             self.table.setItem(row, AUTHOR_COLUMN, name_item)
             self.table.setItem(row, AUTHOR_SORT_COLUMN, sort_item)
             self.table.setItem(row, LINK_COLUMN, link_item)
             note_item = NotesTableWidgetItem()
             self.table.setItem(row, NOTES_COLUMN, note_item)
+            self.table.setItem(row, COUNTS_COLUMN, count_item)
 
             self.set_icon(name_item, id_)
             self.set_icon(sort_item, id_)
@@ -289,7 +317,17 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
             self.notes_utilities.set_icon(note_item, id_, id_ in all_items_that_have_notes)
             row += 1
 
-        self.table.setHorizontalHeaderLabels([_('Author'), _('Author sort'), _('Link'), _('Notes')])
+        headers = { # this depends on the dict being ordered, which is true from python 3.7
+            _('Author'): _('Name of the author'),
+            _('Author sort'): _('Value used to sort this author'),
+            _('Count'): _('Count of books with this author'),
+            _('Link'): _('Link (URL) for this author'),
+            _('Notes'): _('Whether this author has a note attached. The icon changes if the note was created or edited'),
+        }
+        self.table.setHorizontalHeaderLabels(headers.keys())
+        for i,tt in enumerate(headers.values()):
+            header_item = self.table.horizontalHeaderItem(i)
+            header_item.setToolTip(tt)
 
         if self.last_sorted_by == 'sort':
             self.author_sort_order = 1 - self.author_sort_order
@@ -371,7 +409,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
         self.save_state()
 
     def get_column_name(self, column):
-        return ('name', 'sort', 'link', 'notes')[column]
+        return ('name', 'sort', 'count', 'link', 'notes')[column]
 
     def item_is_modified(self, item, id_):
         sub = self.get_column_name(item.column())
@@ -381,7 +419,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
 
     def show_context_menu(self, point):
         self.context_item = self.table.itemAt(point)
-        if self.context_item is None:
+        if self.context_item is None or self.context_item.column() == COUNTS_COLUMN:
             return
         case_menu = QMenu(_('Change case'))
         case_menu.setIcon(QIcon.cached_icon('font_size_larger.png'))
@@ -429,12 +467,14 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
                 else:
                     ca = m.addAction(_('Copy to author'))
                     ca.triggered.connect(self.copy_aus_to_au)
+                    ca = m.addAction(_('Recalculate sort from author'))
+                    ca.triggered.connect(self.do_recalc_one_author_sort)
                 m.addSeparator()
                 m.addMenu(case_menu)
         m.exec(self.table.viewport().mapToGlobal(point))
 
     def undo_cell(self, old_value):
-        if self.context_item.column() == 3:
+        if self.context_item.column() == NOTES_COLUMN:
             self.notes_utilities.undo_note_edit(self.context_item)
         else:
             self.context_item.setText(old_value)
@@ -518,27 +558,33 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
         self.not_found_label_timer.start(1500)
 
     def do_sort(self, section):
-        (self.do_sort_by_author, self.do_sort_by_author_sort, self.do_sort_by_link, self.do_sort_by_notes)[section]()
+        (self.do_sort_by_author, self.do_sort_by_author_sort, self.do_sort_by_count,
+         self.do_sort_by_link, self.do_sort_by_notes)[section]()
 
     def do_sort_by_author(self):
         self.last_sorted_by = 'author'
         self.author_order = 1 - self.author_order
-        self.table.sortByColumn(0, Qt.SortOrder(self.author_order))
+        self.table.sortByColumn(AUTHOR_COLUMN, Qt.SortOrder(self.author_order))
 
     def do_sort_by_author_sort(self):
         self.last_sorted_by = 'sort'
         self.author_sort_order = 1 - self.author_sort_order
-        self.table.sortByColumn(1, Qt.SortOrder(self.author_sort_order))
+        self.table.sortByColumn(AUTHOR_SORT_COLUMN, Qt.SortOrder(self.author_sort_order))
+
+    def do_sort_by_count(self):
+        self.last_sorted_by = 'count'
+        self.count_order = 1 - self.count_order
+        self.table.sortByColumn(COUNTS_COLUMN, Qt.SortOrder(self.count_order))
 
     def do_sort_by_link(self):
         self.last_sorted_by = 'link'
         self.link_order = 1 - self.link_order
-        self.table.sortByColumn(2, Qt.SortOrder(self.link_order))
+        self.table.sortByColumn(LINK_COLUMN, Qt.SortOrder(self.link_order))
 
     def do_sort_by_notes(self):
         self.last_sorted_by = 'notes'
         self.notes_order = 1 - self.notes_order
-        self.table.sortByColumn(3, Qt.SortOrder(self.notes_order))
+        self.table.sortByColumn(NOTES_COLUMN, Qt.SortOrder(self.notes_order))
 
     def accepted(self):
         self.save_state()
@@ -566,6 +612,12 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
                 self.set_icon(item_aus, id_)
             self.table.setFocus(Qt.FocusReason.OtherFocusReason)
 
+    def do_recalc_one_author_sort(self):
+        row = self.context_item.row()
+        aut = str(self.table.item(row, AUTHOR_COLUMN).text()).strip()
+        dest = self.table.item(row, AUTHOR_SORT_COLUMN)
+        dest.setText(str(author_to_author_sort(aut)).rstrip(','))
+
     def do_auth_sort_to_author(self):
         with self.no_cell_changed():
             for row in range(0,self.table.rowCount()):
