@@ -7,14 +7,27 @@ from contextlib import contextmanager
 from functools import partial
 
 from qt.core import (
-    QAbstractItemView, QAction, QApplication, QColor, QDialog,
-    QDialogButtonBox, QFrame, QIcon, QLabel, QMenu, QSize, QStyledItemDelegate,
-    Qt, QTableWidgetItem, QTimer, pyqtSignal, sip,
+    QAbstractItemView,
+    QAction,
+    QApplication,
+    QColor,
+    QDialog,
+    QDialogButtonBox,
+    QFrame,
+    QIcon,
+    QLabel,
+    QMenu,
+    QSize,
+    QStyledItemDelegate,
+    Qt,
+    QTableWidgetItem,
+    QTimer,
+    pyqtSignal,
+    sip,
 )
 
 from calibre import sanitize_file_name
-from calibre.gui2 import (error_dialog, gprefs, question_dialog, choose_files,
-                          choose_save_file)
+from calibre.gui2 import choose_files, choose_save_file, error_dialog, gprefs, question_dialog
 from calibre.gui2.actions.show_quickview import get_quickview_action_plugin
 from calibre.gui2.complete2 import EditWithComplete
 from calibre.gui2.dialogs.confirm_delete import confirm
@@ -22,10 +35,9 @@ from calibre.gui2.dialogs.tag_list_editor_table_widget import TleTableWidget
 from calibre.gui2.dialogs.tag_list_editor_ui import Ui_TagListEditor
 from calibre.gui2.widgets import EnLineEdit
 from calibre.utils.config import prefs
-from calibre.utils.icu import (
-    capitalize, contains, lower as icu_lower, primary_contains, primary_startswith,
-    upper as icu_upper,
-)
+from calibre.utils.icu import capitalize, contains, primary_contains, primary_startswith
+from calibre.utils.icu import lower as icu_lower
+from calibre.utils.icu import upper as icu_upper
 from calibre.utils.titlecase import titlecase
 
 QT_HIDDEN_CLEAR_ACTION = '_q_qlineeditclearaction'
@@ -107,6 +119,7 @@ class CountTableWidgetItem(QTableWidgetItem):
 
     def __init__(self, count):
         QTableWidgetItem.__init__(self, str(count))
+        self.setTextAlignment(Qt.AlignmentFlag.AlignRight|Qt.AlignmentFlag.AlignVCenter)
         self._count = count
 
     def __ge__(self, other):
@@ -332,15 +345,15 @@ class TagListEditor(QDialog, Ui_TagListEditor):
                  ttm_is_first_letter=False, category=None, fm=None, link_map=None):
         QDialog.__init__(self, window)
         Ui_TagListEditor.__init__(self)
+        self.table_column_widths = None
         self.setupUi(self)
 
         from calibre.gui2.ui import get_gui
         self.supports_notes = bool(category and get_gui().current_db.new_api.field_supports_notes(category))
-        self.verticalLayout_2.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.search_box.setMinimumContentsLength(25)
         if category is not None:
             item_map = get_gui().current_db.new_api.get_item_name_map(category)
-            self.original_links = {item_map[k]:v for k,v in link_map.items()}
+            self.original_links = {item_map[k]:v for k,v in link_map.items() if k in item_map}
             self.current_links = copy.copy(self.original_links)
         else:
             self.original_links = {}
@@ -618,12 +631,13 @@ class TagListEditor(QDialog, Ui_TagListEditor):
         # If we don't then the old items remain even if replaced by setItem().
         # I'm not sure if this is standard Qt behavior or behavior triggered by
         # something in this class, but replacing the table fixes it.
+        self.table_column_widths = gprefs.get('tag_list_editor_table_widths', None)
         if self.table is not None:
             self.save_geometry()
-            self.gridlayout.removeWidget(self.table)
+            self.central_layout.removeWidget(self.table)
             sip.delete(self.table)
         self.table = TleTableWidget(self)
-        self.gridlayout.addWidget(self.table, 2, 1, 1, 4)
+        self.central_layout.addWidget(self.table)
 
         self.table.setAlternatingRowColors(True)
         self.table.setSelectionMode(QAbstractItemView.ExtendedSelection)
@@ -673,7 +687,6 @@ class TagListEditor(QDialog, Ui_TagListEditor):
         self.table.setEditTriggers(QAbstractItemView.EditTrigger.EditKeyPressed)
 
         self.restore_geometry(gprefs, 'tag_list_editor_dialog_geometry')
-        self.table_column_widths = gprefs.get('tag_list_editor_table_widths', None)
         if self.table_column_widths is not None:
             for col,width in enumerate(self.table_column_widths):
                 self.table.setColumnWidth(col, width)
@@ -718,6 +731,13 @@ class TagListEditor(QDialog, Ui_TagListEditor):
             tags = self.ordered_tags
 
         select_item = None
+        tooltips = ( # must be in the same order as the columns in the table
+             _('Name of the item'),
+             _('Count of books with this item'),
+             _('Value of the item before it was edited'),
+             _('The link (URL) associated with this item'),
+             _('Whether the item has a note. The icon changes if the note was created or edited')
+        )
         with block_signals(self.table):
             self.name_col = QTableWidgetItem(self.category_name)
             self.table.setHorizontalHeaderItem(VALUE_COLUMN, self.name_col)
@@ -730,6 +750,9 @@ class TagListEditor(QDialog, Ui_TagListEditor):
             if self.supports_notes:
                 self.notes_col = QTableWidgetItem(_('Notes'))
                 self.table.setHorizontalHeaderItem(4, self.notes_col)
+            for i,tt in enumerate(tooltips):
+                header_item = self.table.horizontalHeaderItem(i)
+                header_item.setToolTip(tt)
 
             self.table.setRowCount(len(tags))
             if self.supports_notes:
