@@ -216,7 +216,7 @@ def find_tests(which_tests=None, exclude_tests=None):
 
     if ok('build'):
         from calibre.test_build import find_tests
-        a(find_tests())
+        a(find_tests(only_build=True))
     if ok('srv'):
         from calibre.srv.tests.main import find_tests
         a(find_tests())
@@ -226,6 +226,8 @@ def find_tests(which_tests=None, exclude_tests=None):
     if ok('polish'):
         from calibre.ebooks.oeb.polish.tests.main import find_tests
         a(find_tests())
+        from calibre.ebooks.oeb.polish.tests.structure import find_tests
+        a(find_tests())
     if ok('opf'):
         from calibre.ebooks.metadata.opf2 import suite
         a(suite())
@@ -273,6 +275,8 @@ def find_tests(which_tests=None, exclude_tests=None):
         a(find_tests())
         from calibre.ebooks.html_entities import find_tests
         a(find_tests())
+        from calibre.spell.dictionary import find_tests
+        a(find_tests())
     if ok('misc'):
         from calibre.ebooks.html.input import find_tests
         a(find_tests())
